@@ -1,8 +1,3 @@
-
-# Equivalent to a header guard in C/C++
-# Used to prevent the class/module from being loaded more than once
-unless defined? Logging
-
 require File.expand_path('../logging/utils', __FILE__)
 
 require 'yaml'
@@ -11,7 +6,12 @@ require 'fileutils'
 require 'little-plugger'
 require 'multi_json'
 
-HAVE_SYSLOG = require? 'syslog'
+begin
+  require 'syslog'
+  HAVE_SYSLOG = true
+rescue LoadError
+  HAVE_SYSLOG = false
+end
 
 #
 #
@@ -23,33 +23,13 @@ module Logging
   PATH = ::File.expand_path('../..', __FILE__) + ::File::SEPARATOR
   LEVELS = {}
   LNAMES = []
+  DEFAULT_CAUSE_DEPTH = 8
+
   module Plugins; end
   # :startdoc:
 
   class << self
 
-    # call-seq:
-    #    Logging.configure( filename )
-    #    Logging.configure { block }
-    #
-    # Configures the Logging framework using the configuration information
-    # found in the given file. The file extension should be either '.yaml'
-    # or '.yml' (XML configuration is not yet supported).
-    #
-    def configure( *args, &block )
-      if block
-        return ::Logging::Config::Configurator.process(&block)
-      end
-
-      filename = args.shift
-      raise ArgumentError, 'a filename was not given' if filename.nil?
-
-      case File.extname(filename)
-      when '.yaml', '.yml'
-        ::Logging::Config::YamlConfigurator.load(filename, *args)
-      else raise ArgumentError, 'unknown configuration file format' end
-    end
-
     # call-seq:
     #    Logging.logger( device, age = 7, size = 1048576 )
     #    Logging.logger( device, age = 'weekly' )
@@ -117,9 +97,9 @@ module Logging
       layout = ::Logging::Layouts::Pattern.new(l_opts)
 
       a_opts = Hash.new
-      a_opts[:size] = size if size.instance_of?(Fixnum)
+      a_opts[:size] = size if size.is_a?(Integer)
       a_opts[:age]  = age  if age.instance_of?(String)
-      a_opts[:keep] = keep if keep.instance_of?(Fixnum)
+      a_opts[:keep] = keep if keep.is_a?(Integer)
       a_opts[:filename] = dev if dev.instance_of?(String)
       a_opts[:layout] = layout
       a_opts.merge! opts
@@ -185,34 +165,6 @@ module Logging
       self
     end
 
-    # call-seq:
-    #    Logging.consolidate( 'First::Name', 'Second::Name', ... )
-    #
-    # Consolidate all loggers under the given namespace. All child loggers
-    # in the namespace will use the "consolidated" namespace logger instead
-    # of creating a new logger for each class or module.
-    #
-    # If the "root" logger name is passed to this method then all loggers
-    # will consolidate to the root logger. In other words, only the root
-    # logger will be created, and it will be used by all classes and modules
-    # in the application.
-    #
-    # ==== Example
-    #
-    #    Logging.consolidate( 'Foo' )
-    #
-    #    foo = Logging.logger['Foo']
-    #    bar = Logging.logger['Foo::Bar']
-    #    baz = Logging.logger['Baz']
-    #
-    #    foo.object_id == bar.object_id    #=> true
-    #    foo.object_id == baz.object_id    #=> false
-    #
-    def consolidate( *args )
-      ::Logging::Repository.instance.add_master(*args)
-      self
-    end
-
     # call-seq:
     #    include Logging.globally
     #    include Logging.globally( :logger )
@@ -305,6 +257,8 @@ module Logging
       longest = 'off' if longest.length < 3
       module_eval "MAX_LEVEL_LENGTH = #{longest.length}", __FILE__, __LINE__
 
+      self.cause_depth = nil unless defined? @cause_depth
+
       initialize_plugins
       levels.keys
     end
@@ -361,12 +315,74 @@ module Logging
           end
     end
 
-    # Returns the version string for the library.
+    # Set the default UTC offset used when formatting time values sent to the
+    # appenders. If left unset, the default local time zone will be used for
+    # time values. This method accepts the `utc_offset` format supported by the
+    # `Time#localtime` method in Ruby.
     #
-    def version
-      @version ||= File.read(path('version.txt')).strip
+    # Passing "UTC" or `0` as the UTC offset will cause all times to be reported
+    # in the UTC timezone.
+    #
+    #   Logging.utc_offset = "-07:00"  # Mountain Standard Time in North America
+    #   Logging.utc_offset = "+01:00"  # Central European Time
+    #   Logging.utc_offset = "UTC"     # UTC
+    #   Logging.utc_offset = 0         # UTC
+    #
+    def utc_offset=( value )
+      @utc_offset = case value
+        when nil;             nil
+        when "UTC", "GMT", 0; 0
+        else
+          Time.now.localtime(value)
+          value
+        end
     end
 
+    attr_reader :utc_offset
+
+    # Set the default Exception#cause depth used when formatting Exceptions.
+    # This sets the maximum number of nested errors that will be formatted by
+    # the layouts before giving up. This is used to avoid extremely large
+    # outputs.
+    #
+    #   Logging.cause_depth = nil    # set to the DEFAULT_CAUSE_DEPTH
+    #   Logging.cause_depth = 0      # do not show any exception causes
+    #   Logging.cause_depth = 1024   # show up to 1024 causes
+    #   Logging.cause_depth = -1     # results in the DEFAULT_CAUSE_DEPTH
+    #
+    def cause_depth=( value )
+      if value.nil?
+        @cause_depth = DEFAULT_CAUSE_DEPTH
+      else
+        value = Integer(value)
+        @cause_depth = value < 0 ? DEFAULT_CAUSE_DEPTH : value
+      end
+    end
+
+    attr_reader :cause_depth
+
+    # Used to define a `basepath` that will be removed from filenames when
+    # reporting tracing information for log events. Normally you would set this
+    # to the root of your project:
+    #
+    #   Logging.basepath = "/home/user/nifty_project"
+    #
+    # Or if you are in a Rails environment:
+    #
+    #   Logging.basepath = Rails.root.to_s
+    #
+    # The basepath is expanded to a full path with trailing slashes removed.
+    # This setting will be cleared by a call to `Logging.reset`.
+    def basepath=( path )
+      if path.nil? || path.to_s.empty?
+        @basepath = nil
+      else
+        @basepath = File.expand_path(path)
+      end
+    end
+
+    attr_reader :basepath
+
     # Returns the library path for the module. If any arguments are given,
     # they will be joined to the end of the library path using
     # <tt>File.join</tt>.
@@ -434,11 +450,11 @@ module Logging
     #                    that the logger will *not* pass log events up to the
     #                    parent logger
     #
-    #    4) trace      - a "+T" shows that the logger will include trace
-    #                    information in generated log events (this includes
-    #                    filename and line number of the log message; "-T"
-    #                    shows that the logger does not include trace
-    #                    information in the log events)
+    #    4) tracing    - a "+T" shows that the logger will include caller
+    #                    tracing information in generated log events (this
+    #                    includes filename and line number of the log
+    #                    message); "-T" shows that the logger does not include
+    #                    caller tracing information in the log events
     #
     # If a logger has appenders then they are listed, one per line,
     # immediately below the logger. Appender lines are pre-pended with a
@@ -461,9 +477,9 @@ module Logging
     # to false. It uses its own appender to send messages to stderr.
     #
     def show_configuration( io = STDOUT, logger = 'root', indent = 0 )
-      logger = ::Logging::Logger[logger] unless ::Logging::Logger === logger
+      logger = ::Logging::Logger[logger] unless logger.is_a?(::Logging::Logger)
 
-      logger._dump_configuration(io, indent)
+      io << logger._dump_configuration(indent)
 
       indent += 2
       children = ::Logging::Repository.instance.children(logger.name)
@@ -471,7 +487,7 @@ module Logging
         ::Logging.show_configuration(io, child, indent)
       end
 
-      self
+      io
     end
 
     # :stopdoc:
@@ -497,6 +513,14 @@ module Logging
       ::Logging::Logger[::Logging].__send__(levelify(LNAMES[level]), &block)
     end
 
+    # Internal logging method for handling exceptions. If the
+    # `Thread#abort_on_exception` flag is set then the
+    # exception will be raised again.
+    def log_internal_error( err )
+      log_internal(-2) { err }
+      raise err if Thread.abort_on_exception
+    end
+
     # Close all appenders
     def shutdown( *args )
       return unless initialized?
@@ -514,8 +538,11 @@ module Logging
       LEVELS.clear
       LNAMES.clear
       remove_instance_variable :@backtrace if defined? @backtrace
+      remove_instance_variable :@basepath  if defined? @basepath
       remove_const :MAX_LEVEL_LENGTH if const_defined? :MAX_LEVEL_LENGTH
       remove_const :OBJ_FORMAT if const_defined? :OBJ_FORMAT
+      self.utc_offset  = nil
+      self.cause_depth = nil
       self
     end
 
@@ -526,22 +553,21 @@ module Logging
     # :startdoc:
   end
 
+  require libpath('logging/version')
   require libpath('logging/appender')
   require libpath('logging/layout')
+  require libpath('logging/filter')
   require libpath('logging/log_event')
   require libpath('logging/logger')
   require libpath('logging/repository')
   require libpath('logging/root_logger')
-  require libpath('logging/stats')
   require libpath('logging/color_scheme')
   require libpath('logging/appenders')
   require libpath('logging/layouts')
+  require libpath('logging/filters')
   require libpath('logging/proxy')
   require libpath('logging/diagnostic_context')
 
-  require libpath('logging/config/configurator')
-  require libpath('logging/config/yaml_configurator')
-
   require libpath('logging/rails_compat')
 end  # module Logging
 
@@ -554,6 +580,3 @@ end  # module Logging
 # application. This is required when daemonizing.
 #
 ObjectSpace.define_finalizer self, Logging.method(:shutdown)
-
-end  # unless defined?
-
