@@ -114,7 +114,7 @@ class Appender
   #
   # Set the level for this appender; log events below this level will be
   # ignored by this appender. The level can be either a +String+, a
-  # +Symbol+, or a +Fixnum+. An +ArgumentError+ is raised if this is not
+  # +Symbol+, or an +Integer+. An +ArgumentError+ is raised if this is not
   # the case.
   #
   # There are two special levels -- "all" and "off". The former will
@@ -138,7 +138,7 @@ class Appender
   def level=( level )
     lvl = case level
           when String, Symbol; ::Logging::level_num(level)
-          when Fixnum; level
+          when Integer; level
           when nil; 0
           else
             raise ArgumentError,
@@ -251,17 +251,16 @@ class Appender
     self
   end
 
+  # Save off the original `to_s` for use in tests
+  alias_method :_to_s, :to_s
+
   # call-seq:
-  #     inspect    => string
+  #     to_s => string
   #
   # Returns a string representation of the appender.
   #
-  def inspect
-    "<%s:0x%x name=\"%s\">" % [
-        self.class.name.sub(%r/^Logging::/, ''),
-        self.object_id,
-        self.name
-    ]
+  def to_s
+    "<%s name=\"%s\">" % [self.class.name.sub(%r/^Logging::/, ''), self.name]
   end
 
   # Returns the current Encoding for the appender or nil if an encoding has
