@@ -2,7 +2,7 @@ module Logging::Appenders
 
   # Accessor / Factory for the RollingFile appender.
   def self.rolling_file( *args )
-    return ::Logging::Appenders::RollingFile if args.empty?
+    fail ArgumentError, '::Logging::Appenders::RollingFile needs a name as first argument.' if args.empty?
     ::Logging::Appenders::RollingFile.new(*args)
   end
 
@@ -141,6 +141,15 @@ module Logging::Appenders
       @roller.copy_file
     end
 
+    # Returns the modification time of the copy file if one exists. Otherwise
+    # returns `nil`.
+    def copy_file_mtime
+      return nil unless ::File.exist?(copy_file)
+      ::File.mtime(copy_file)
+    rescue Errno::ENOENT
+      nil
+    end
+
     # Write the given _event_ to the log file. The log file will be rolled
     # if the maximum file size is exceeded or if the file is older than the
     # maximum age.
@@ -148,7 +157,7 @@ module Logging::Appenders
       return self if @io.nil?
 
       str = str.force_encoding(encoding) if encoding && str.encoding != encoding
-      @io.flock_sh { @io.syswrite str }
+      @io.flock_sh { @io.write str }
 
       if roll_required?
         @io.flock? {
@@ -166,7 +175,8 @@ module Logging::Appenders
 
     # Returns +true+ if the log file needs to be rolled.
     def roll_required?
-      return false if ::File.exist?(copy_file) && (Time.now - ::File.mtime(copy_file)) < 180
+      mtime = copy_file_mtime
+      return false if mtime && (Time.now - mtime) < 180
 
       # check if max size has been exceeded
       s = @size ? ::File.size(filename) > @size : false
