@@ -83,7 +83,7 @@ module Logging::Layouts
   # events is configured to generate tracing information. If this is not
   # the case these fields will always be empty.
   #
-  # The directives for include diagnostic context information in the log
+  # The directives for including diagnostic context information in the log
   # messages are X and x. For the Mapped Diagnostic Context the directive must
   # be accompanied by the key identifying the value to insert into the log
   # message. The X directive can appear multiple times to include multiple
@@ -164,14 +164,12 @@ module Logging::Layouts
     def self.create_date_format_methods( pl )
       code = "undef :format_date if method_defined? :format_date\n"
       code << "def format_date( time )\n"
+      code << "time = apply_utc_offset(time)\n"
       if pl.date_method.nil?
         if pl.date_pattern =~ %r/%s/
-          code << <<-CODE
-            dp = '#{pl.date_pattern}'.gsub('%s','%06d' % time.usec)
-            time.strftime dp
-          CODE
+          code << "time.strftime('#{pl.date_pattern.gsub('%s','%6N')}')\n"
         else
-          code << "time.strftime '#{pl.date_pattern}'\n"
+          code << "time.strftime('#{pl.date_pattern}')\n"
         end
       else
         code << "time.#{pl.date_method}\n"
@@ -206,7 +204,8 @@ module Logging::Layouts
     #
     #    :pattern       =>  "[%d] %-5l -- %c : %m\n"
     #    :date_pattern  =>  "%Y-%m-%d %H:%M:%S"
-    #    :date_method   =>  'usec' or 'to_s'
+    #    :date_method   =>  "usec" or "to_s"
+    #    :utc_offset    =>  "-06:00" or -21600 or "UTC"
     #    :color_scheme  =>  :default
     #
     # If used, :date_method will supersede :date_pattern.
@@ -219,7 +218,7 @@ module Logging::Layouts
     #
     def initialize( opts = {} )
       super
-      @created_at = Time.now
+      @created_at = Time.now.freeze
 
       @date_pattern = opts.fetch(:date_pattern, nil)
       @date_method = opts.fetch(:date_method, nil)
