@@ -20,24 +20,30 @@ module TestAppenders
       FileUtils.chmod 0444, File.join(TMP, 'uw_file')
     end
 
+    def test_factory_method_validates_input
+      assert_raise(ArgumentError) do
+        Logging.appenders.file
+      end
+    end
+
     def test_class_assert_valid_logfile
       log = File.join(TMP, 'uw_dir', 'file.log')
       assert_raise(ArgumentError) do
-        Logging.appenders.file.assert_valid_logfile(log)
+        Logging.appenders.file(log).class.assert_valid_logfile(log)
       end
 
       log = File.join(TMP, 'dir')
       assert_raise(ArgumentError) do
-        Logging.appenders.file.assert_valid_logfile(log)
+        Logging.appenders.file(log).class.assert_valid_logfile(log)
       end
 
       log = File.join(TMP, 'uw_file')
       assert_raise(ArgumentError) do
-        Logging.appenders.file.assert_valid_logfile(log)
+        Logging.appenders.file(log).class.assert_valid_logfile(log)
       end
 
       log = File.join(TMP, 'file.log')
-      assert Logging.appenders.file.assert_valid_logfile(log)
+      assert Logging.appenders.file(log).class.assert_valid_logfile(log)
     end
 
     def test_initialize
@@ -100,14 +106,13 @@ module TestAppenders
 
       def test_encoding
         log = File.join(TMP, 'file-encoding.log')
-        #appender = Logging.appenders.file(NAME, :filename => log, :encoding => 'ISO-8859-16')
         appender = Logging.appenders.file(NAME, :filename => log, :encoding => 'ASCII')
 
         appender << "A normal line of text\n"
         appender << "ümlaut\n"
         appender.close
 
-        lines = File.readlines(log)
+        lines = File.readlines(log, :encoding => 'UTF-8')
         assert_equal "A normal line of text\n", lines[0]
         assert_equal "ümlaut\n", lines[1]
 
