@@ -39,6 +39,52 @@ module TestLogging
       assert_raise(ArgumentError) {::Logging.backtrace 'foo'}
     end
 
+    def test_utc_offset
+      assert_nil ::Logging.utc_offset
+
+      ::Logging.utc_offset = 0
+      assert_equal 0, ::Logging.utc_offset
+
+      ::Logging.utc_offset = "UTC"
+      assert_equal 0, ::Logging.utc_offset
+
+      ::Logging.utc_offset = "+01:00"
+      assert_equal "+01:00", ::Logging.utc_offset
+
+      assert_raise(ArgumentError) {::Logging.utc_offset = "06:00"}
+    end
+
+    def test_cause_depth
+      assert_equal ::Logging::DEFAULT_CAUSE_DEPTH, ::Logging.cause_depth
+
+      ::Logging.cause_depth = 0
+      assert_equal 0, ::Logging.cause_depth
+
+      ::Logging.cause_depth = nil
+      assert_equal ::Logging::DEFAULT_CAUSE_DEPTH, ::Logging.cause_depth
+
+      ::Logging.cause_depth = "1024"
+      assert_equal 1024, ::Logging.cause_depth
+
+      ::Logging.cause_depth = -1
+      assert_equal ::Logging::DEFAULT_CAUSE_DEPTH, ::Logging.cause_depth
+
+      assert_raise(ArgumentError) {::Logging.cause_depth = "foo"}
+    end
+
+    def test_basepath
+      assert_nil ::Logging.basepath
+
+      ::Logging.basepath = ""
+      assert_nil ::Logging.basepath
+
+      ::Logging.basepath = "./"
+      assert_equal File.expand_path("../../", __FILE__), ::Logging.basepath
+
+      ::Logging.reset
+      assert_nil ::Logging.basepath
+    end
+
     def test_logger
       assert_raise(TypeError) {::Logging.logger []}
 
